netapp_ontap.models.aggregate_data_encryption API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.aggregate_data_encryption`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AggregateDataEncryptionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AggregateDataEncryption object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `drive_protection_enabled GET`

    Specifies whether the aggregate uses self-encrypting drives with data protection enabled.

  `software_encryption_enabled GET POST PATCH`

    Specifies whether NetApp aggregate encryption is enabled. All data in the aggregate is encrypted.